summaryrefslogtreecommitdiff
path: root/sc
diff options
context:
space:
mode:
authorNoel Grandin <noel@peralex.com>2016-04-20 10:34:01 +0200
committerNoel Grandin <noel@peralex.com>2016-04-21 08:32:47 +0200
commit5abc669599001bf888b97c4d3c2715e1fb7523b9 (patch)
tree2407c6fc040a795e6ffc69de02ba940285c04c7f /sc
parent5bb308a9ad16f6002486a60e4a753693818580b6 (diff)
new plugin stylepolice
check for local variables which follow our member field naming convention, which is highly confusing Change-Id: Idacedf7145d09843e96a584237b385f7662eea10
Diffstat (limited to 'sc')
-rw-r--r--sc/qa/extras/check_data_pilot_field.cxx4
-rw-r--r--sc/qa/extras/check_data_pilot_table.cxx4
-rw-r--r--sc/qa/extras/check_xcell_ranges_query.cxx10
-rw-r--r--sc/qa/unit/subsequent_export-test.cxx16
-rw-r--r--sc/source/core/data/dpsave.cxx4
-rw-r--r--sc/source/filter/oox/workbookfragment.cxx8
-rw-r--r--sc/source/filter/xml/xmlexprt.cxx28
-rw-r--r--sc/source/ui/Accessibility/AccessibleCellBase.cxx6
-rw-r--r--sc/source/ui/cctrl/checklistmenu.cxx6
-rw-r--r--sc/source/ui/condformat/condformatdlgentry.cxx4
-rw-r--r--sc/source/ui/miscdlgs/anyrefdg.cxx10
-rw-r--r--sc/source/ui/namedlg/namedlg.cxx4
-rw-r--r--sc/source/ui/sidebar/CellAppearancePropertyPanel.cxx8
-rw-r--r--sc/source/ui/sidebar/CellBorderUpdater.cxx4
-rw-r--r--sc/source/ui/vba/vbaborders.cxx10
-rw-r--r--sc/source/ui/vba/vbachart.cxx18
-rw-r--r--sc/source/ui/vba/vbawindows.cxx6
-rw-r--r--sc/source/ui/vba/vbaworksheets.cxx6
18 files changed, 78 insertions, 78 deletions
diff --git a/sc/qa/extras/check_data_pilot_field.cxx b/sc/qa/extras/check_data_pilot_field.cxx
index 3ff8c65e9bf7..24c7ffb90f9a 100644
--- a/sc/qa/extras/check_data_pilot_field.cxx
+++ b/sc/qa/extras/check_data_pilot_field.cxx
@@ -168,8 +168,8 @@ uno::Reference< uno::XInterface > CheckDataPilotField::init()
uno::Reference< container::XIndexAccess > IA = DPDsc->getDataPilotFields();
uno::Reference<uno::XInterface> xDataPilotFieldObject;
- uno::Any mAny = IA->getByIndex(0);
- CPPUNIT_ASSERT(mAny >>= xDataPilotFieldObject);
+ data = IA->getByIndex(0);
+ CPPUNIT_ASSERT(data >>= xDataPilotFieldObject);
mxObject = xDataPilotFieldObject;
return xDataPilotFieldObject;
diff --git a/sc/qa/extras/check_data_pilot_table.cxx b/sc/qa/extras/check_data_pilot_table.cxx
index b5e786b8cfbc..11c3ee336eff 100644
--- a/sc/qa/extras/check_data_pilot_table.cxx
+++ b/sc/qa/extras/check_data_pilot_table.cxx
@@ -166,8 +166,8 @@ uno::Reference< uno::XInterface > CheckDataPilotTable::init()
DPT->insertNewByName("DataPilotTable", sCellAdress, DPDsc);
uno::Reference<uno::XInterface> xDataPilotTableObject;
- uno::Any mAny = DPT->getByName( DPT->getElementNames()[0] );
- CPPUNIT_ASSERT(mAny >>= xDataPilotTableObject);
+ data = DPT->getByName( DPT->getElementNames()[0] );
+ CPPUNIT_ASSERT(data >>= xDataPilotTableObject);
mxObject = xDataPilotTableObject;
return xDataPilotTableObject;
diff --git a/sc/qa/extras/check_xcell_ranges_query.cxx b/sc/qa/extras/check_xcell_ranges_query.cxx
index 77c0bb63e5f4..ad8f0b0cc31f 100644
--- a/sc/qa/extras/check_xcell_ranges_query.cxx
+++ b/sc/qa/extras/check_xcell_ranges_query.cxx
@@ -64,11 +64,11 @@ uno::Reference< uno::XInterface > CheckXCellRangesQuery::init()
// Load an empty document.
mxComponent = loadFromDesktop("private:factory/scalc");
- uno::Reference< sheet::XSpreadsheetDocument > m_xSheetDoc(mxComponent, uno::UNO_QUERY_THROW);
- CPPUNIT_ASSERT_MESSAGE("no calc document!", m_xSheetDoc.is());
+ uno::Reference< sheet::XSpreadsheetDocument > xSheetDoc(mxComponent, uno::UNO_QUERY_THROW);
+ CPPUNIT_ASSERT_MESSAGE("no calc document!", xSheetDoc.is());
// Getting spreadsheet
- uno::Reference< sheet::XSpreadsheets > oSheets = m_xSheetDoc->getSheets();
+ uno::Reference< sheet::XSpreadsheets > oSheets = xSheetDoc->getSheets();
uno::Reference< container::XIndexAccess > oIndexSheets(oSheets, uno::UNO_QUERY_THROW);
uno::Any aAny = oIndexSheets->getByIndex(0);
uno::Reference<container::XNamed> xNamed;
@@ -118,9 +118,9 @@ void CheckXCellRangesQuery::checkEmptyCell()
void CheckXCellRangesQuery::checkFilledCell()
{
- uno::Reference< sheet::XSpreadsheet > m_xSpreadSheet(init(), uno::UNO_QUERY_THROW);
+ uno::Reference< sheet::XSpreadsheet > xSpreadSheet(init(), uno::UNO_QUERY_THROW);
// fill the cell with a value
- m_xSpreadSheet->getCellByPosition(2, 3)->setValue(15);
+ xSpreadSheet->getCellByPosition(2, 3)->setValue(15);
// compare an cell with value 5 with a cell with value 15
_queryColumnDifferences(sSheetName + ".C4");
diff --git a/sc/qa/unit/subsequent_export-test.cxx b/sc/qa/unit/subsequent_export-test.cxx
index cf75d8766fc7..7b2e78ff7533 100644
--- a/sc/qa/unit/subsequent_export-test.cxx
+++ b/sc/qa/unit/subsequent_export-test.cxx
@@ -1586,14 +1586,14 @@ void ScExportTest::testBordersExchangeXLSX()
CPPUNIT_ASSERT(xDocSh.Is());
ScDocument& rDoc = xDocSh->GetDocument();
- for (size_t mnCol = 0; mnCol < nMaxCol; ++mnCol)
+ for (size_t nCol = 0; nCol < nMaxCol; ++nCol)
{
- for (size_t mnRow = 0; mnRow < nMaxRow; ++mnRow)
+ for (size_t nRow = 0; nRow < nMaxRow; ++nRow)
{
const editeng::SvxBorderLine* pLineTop = nullptr;
const editeng::SvxBorderLine* pLineBottom = nullptr;
- rDoc.GetBorderLines(mnCol + 2, (mnRow * 2) + 8, 0, nullptr, &pLineTop, nullptr, &pLineBottom);
- if((mnCol < 5) && (mnRow == 6))
+ rDoc.GetBorderLines(nCol + 2, (nRow * 2) + 8, 0, nullptr, &pLineTop, nullptr, &pLineBottom);
+ if((nCol < 5) && (nRow == 6))
{ // in this range no lines
CPPUNIT_ASSERT(pLineTop == nullptr);
CPPUNIT_ASSERT(pLineBottom == nullptr);
@@ -1605,13 +1605,13 @@ void ScExportTest::testBordersExchangeXLSX()
CPPUNIT_ASSERT(pLineBottom);
}
- CPPUNIT_ASSERT_EQUAL_MESSAGE("Top Border-Line-Style wrong", aCheckBorderWidth[mnCol][mnRow].BorderStyleTop,
+ CPPUNIT_ASSERT_EQUAL_MESSAGE("Top Border-Line-Style wrong", aCheckBorderWidth[nCol][nRow].BorderStyleTop,
pLineTop->GetBorderLineStyle());
- CPPUNIT_ASSERT_EQUAL_MESSAGE("Bottom Border-Line-Style wrong", aCheckBorderWidth[mnCol][mnRow].BorderStyleBottom,
+ CPPUNIT_ASSERT_EQUAL_MESSAGE("Bottom Border-Line-Style wrong", aCheckBorderWidth[nCol][nRow].BorderStyleBottom,
pLineBottom->GetBorderLineStyle());
- CPPUNIT_ASSERT_EQUAL_MESSAGE("Top Width-Line wrong", aCheckBorderWidth[mnCol][mnRow].WidthTop,
+ CPPUNIT_ASSERT_EQUAL_MESSAGE("Top Width-Line wrong", aCheckBorderWidth[nCol][nRow].WidthTop,
pLineTop->GetWidth());
- CPPUNIT_ASSERT_EQUAL_MESSAGE("Bottom Width-Line wrong", aCheckBorderWidth[mnCol][mnRow].WidthBottom,
+ CPPUNIT_ASSERT_EQUAL_MESSAGE("Bottom Width-Line wrong", aCheckBorderWidth[nCol][nRow].WidthBottom,
pLineBottom->GetWidth());
}
}
diff --git a/sc/source/core/data/dpsave.cxx b/sc/source/core/data/dpsave.cxx
index 22dcb6b93077..20c3488f524e 100644
--- a/sc/source/core/data/dpsave.cxx
+++ b/sc/source/core/data/dpsave.cxx
@@ -1366,8 +1366,8 @@ void ScDPSaveData::BuildAllDimensionMembers(ScDPTableData* pData)
long nDimIndex = itr->second;
const std::vector<SCROW>& rMembers = pData->GetColumnEntries(nDimIndex);
- size_t mMemberCount = rMembers.size();
- for (size_t j = 0; j < mMemberCount; ++j)
+ size_t nMemberCount = rMembers.size();
+ for (size_t j = 0; j < nMemberCount; ++j)
{
const ScDPItemData* pMemberData = pData->GetMemberById( nDimIndex, rMembers[j] );
OUString aMemName = pData->GetFormattedString(nDimIndex, *pMemberData);
diff --git a/sc/source/filter/oox/workbookfragment.cxx b/sc/source/filter/oox/workbookfragment.cxx
index 5ef4b544b9cb..82980ab646a2 100644
--- a/sc/source/filter/oox/workbookfragment.cxx
+++ b/sc/source/filter/oox/workbookfragment.cxx
@@ -237,7 +237,7 @@ public:
// the small safe section of the inner loop in
// sheetdatacontext.cxx
SAL_INFO( "sc.filter", "start wait on solar\n" );
- SolarMutexGuard maGuard;
+ SolarMutexGuard aGuard;
SAL_INFO( "sc.filter", "got solar\n" );
std::unique_ptr<oox::core::FastParser> xParser(
@@ -393,7 +393,7 @@ void WorkbookFragment::finalizeImport()
loaded. Additionally, the instances of the WorkbookGlobals structures
have to be stored for every sheet. */
SheetFragmentVector aSheetFragments;
- std::vector<WorksheetHelper*> maHelpers;
+ std::vector<WorksheetHelper*> aHelpers;
WorksheetBuffer& rWorksheets = getWorksheets();
sal_Int32 nWorksheetCount = rWorksheets.getWorksheetCount();
for( sal_Int32 nWorksheet = 0; nWorksheet < nWorksheetCount; ++nWorksheet )
@@ -456,7 +456,7 @@ void WorkbookFragment::finalizeImport()
if( xFragment.is() )
{
aSheetFragments.push_back( SheetFragmentHandler( xSheetGlob, xFragment.get() ) );
- maHelpers.push_back(xFragment.get());
+ aHelpers.push_back(xFragment.get());
}
}
}
@@ -500,7 +500,7 @@ void WorkbookFragment::finalizeImport()
recalcFormulaCells();
- for( std::vector<WorksheetHelper*>::iterator aIt = maHelpers.begin(), aEnd = maHelpers.end(); aIt != aEnd; ++aIt )
+ for( std::vector<WorksheetHelper*>::iterator aIt = aHelpers.begin(), aEnd = aHelpers.end(); aIt != aEnd; ++aIt )
{
(*aIt)->finalizeDrawingImport();
}
diff --git a/sc/source/filter/xml/xmlexprt.cxx b/sc/source/filter/xml/xmlexprt.cxx
index bf7d87f22795..b38de6979951 100644
--- a/sc/source/filter/xml/xmlexprt.cxx
+++ b/sc/source/filter/xml/xmlexprt.cxx
@@ -4327,9 +4327,9 @@ void ScXMLExport::ExportConditionalFormat(SCTAB nTab)
else if(pFormatEntry->GetType() == condformat::COLORSCALE)
{
SvXMLElementExport aElementColorScale(*this, XML_NAMESPACE_CALC_EXT, XML_COLOR_SCALE, true, true);
- const ScColorScaleFormat& mrColorScale = static_cast<const ScColorScaleFormat&>(*pFormatEntry);
- for(ScColorScaleEntries::const_iterator it = mrColorScale.begin();
- it != mrColorScale.end(); ++it)
+ const ScColorScaleFormat& rColorScale = static_cast<const ScColorScaleFormat&>(*pFormatEntry);
+ for(ScColorScaleEntries::const_iterator it = rColorScale.begin();
+ it != rColorScale.end(); ++it)
{
if(it[0]->GetType() == COLORSCALE_FORMULA)
{
@@ -4423,19 +4423,19 @@ void ScXMLExport::ExportConditionalFormat(SCTAB nTab)
}
else if(pFormatEntry->GetType() == condformat::ICONSET)
{
- const ScIconSetFormat& mrIconSet = static_cast<const ScIconSetFormat&>(*pFormatEntry);
- OUString aIconSetName = getIconSetName(mrIconSet.GetIconSetData()->eIconSetType);
+ const ScIconSetFormat& rIconSet = static_cast<const ScIconSetFormat&>(*pFormatEntry);
+ OUString aIconSetName = getIconSetName(rIconSet.GetIconSetData()->eIconSetType);
AddAttribute( XML_NAMESPACE_CALC_EXT, XML_ICON_SET_TYPE, aIconSetName );
- if (mrIconSet.GetIconSetData()->mbCustom)
+ if (rIconSet.GetIconSetData()->mbCustom)
AddAttribute(XML_NAMESPACE_CALC_EXT, XML_CUSTOM, OUString::boolean(true));
SvXMLElementExport aElementColorScale(*this, XML_NAMESPACE_CALC_EXT, XML_ICON_SET, true, true);
- if (mrIconSet.GetIconSetData()->mbCustom)
+ if (rIconSet.GetIconSetData()->mbCustom)
{
for (std::vector<std::pair<ScIconSetType, sal_Int32> >::const_iterator
- it = mrIconSet.GetIconSetData()->maCustomVector.begin();
- it != mrIconSet.GetIconSetData()->maCustomVector.end(); ++it)
+ it = rIconSet.GetIconSetData()->maCustomVector.begin();
+ it != rIconSet.GetIconSetData()->maCustomVector.end(); ++it)
{
AddAttribute(XML_NAMESPACE_CALC_EXT, XML_CUSTOM_ICONSET_NAME, getIconSetName(it->first));
AddAttribute(XML_NAMESPACE_CALC_EXT, XML_CUSTOM_ICONSET_INDEX, OUString::number(it->second));
@@ -4444,9 +4444,9 @@ void ScXMLExport::ExportConditionalFormat(SCTAB nTab)
}
- if(!mrIconSet.GetIconSetData()->mbShowValue)
+ if(!rIconSet.GetIconSetData()->mbShowValue)
AddAttribute(XML_NAMESPACE_CALC_EXT, XML_SHOW_VALUE, XML_FALSE);
- for (auto const& it : mrIconSet)
+ for (auto const& it : rIconSet)
{
if(it->GetType() == COLORSCALE_FORMULA)
{
@@ -4462,9 +4462,9 @@ void ScXMLExport::ExportConditionalFormat(SCTAB nTab)
}
else if(pFormatEntry->GetType() == condformat::DATE)
{
- const ScCondDateFormatEntry& mrDateFormat = static_cast<const ScCondDateFormatEntry&>(*pFormatEntry);
- OUString aDateType = getDateStringForType(mrDateFormat.GetDateType());
- OUString aStyleName = ScStyleNameConversion::DisplayToProgrammaticName(mrDateFormat.GetStyleName(), SFX_STYLE_FAMILY_PARA );
+ const ScCondDateFormatEntry& rDateFormat = static_cast<const ScCondDateFormatEntry&>(*pFormatEntry);
+ OUString aDateType = getDateStringForType(rDateFormat.GetDateType());
+ OUString aStyleName = ScStyleNameConversion::DisplayToProgrammaticName(rDateFormat.GetStyleName(), SFX_STYLE_FAMILY_PARA );
AddAttribute( XML_NAMESPACE_CALC_EXT, XML_STYLE, aStyleName);
AddAttribute( XML_NAMESPACE_CALC_EXT, XML_DATE, aDateType);
SvXMLElementExport aElementDateFormat(*this, XML_NAMESPACE_CALC_EXT, XML_DATE_IS, true, true);
diff --git a/sc/source/ui/Accessibility/AccessibleCellBase.cxx b/sc/source/ui/Accessibility/AccessibleCellBase.cxx
index 3c3a218d3936..436e0d63b3b2 100644
--- a/sc/source/ui/Accessibility/AccessibleCellBase.cxx
+++ b/sc/source/ui/Accessibility/AccessibleCellBase.cxx
@@ -320,7 +320,7 @@ OUString SAL_CALL ScAccessibleCellBase::GetNote()
{
SolarMutexGuard aGuard;
IsObjectValid();
- OUString msNote;
+ OUString sNote;
if (mpDoc)
{
SfxObjectShell* pObjSh = mpDoc->GetDocumentShell();
@@ -349,7 +349,7 @@ OUString SAL_CALL ScAccessibleCellBase::GetNote()
uno::Reference <text::XSimpleText> xText (xSheetAnnotation, uno::UNO_QUERY);
if (xText.is())
{
- msNote = xText->getString();
+ sNote = xText->getString();
}
}
}
@@ -359,7 +359,7 @@ OUString SAL_CALL ScAccessibleCellBase::GetNote()
}
}
}
- return msNote;
+ return sNote;
}
#include <com/sun/star/table/ShadowFormat.hpp>
diff --git a/sc/source/ui/cctrl/checklistmenu.cxx b/sc/source/ui/cctrl/checklistmenu.cxx
index fa943fc85ddb..e8cb32d2b13f 100644
--- a/sc/source/ui/cctrl/checklistmenu.cxx
+++ b/sc/source/ui/cctrl/checklistmenu.cxx
@@ -1133,12 +1133,12 @@ void ScCheckListMenuWindow::packWindow()
void ScCheckListMenuWindow::setAllMemberState(bool bSet)
{
size_t n = maMembers.size();
- std::set<SvTreeListEntry*> maParents;
+ std::set<SvTreeListEntry*> aParents;
for (size_t i = 0; i < n; ++i)
{
- maParents.insert(maMembers[i].mpParent);
+ aParents.insert(maMembers[i].mpParent);
}
- for (auto itr = maParents.begin(), itrEnd = maParents.end(); itr != itrEnd; ++itr)
+ for (auto itr = aParents.begin(), itrEnd = aParents.end(); itr != itrEnd; ++itr)
{
if (!(*itr))
{
diff --git a/sc/source/ui/condformat/condformatdlgentry.cxx b/sc/source/ui/condformat/condformatdlgentry.cxx
index 795467cadc83..7ca4a1838d06 100644
--- a/sc/source/ui/condformat/condformatdlgentry.cxx
+++ b/sc/source/ui/condformat/condformatdlgentry.cxx
@@ -127,8 +127,8 @@ void ScCondFrmtEntry::Select()
void ScCondFrmtEntry::Deselect()
{
- OUString maCondText = GetExpressionString();
- maFtCondition->SetText(maCondText);
+ OUString aCondText = GetExpressionString();
+ maFtCondition->SetText(aCondText);
maFtCondition->Show();
maLbType->Hide();
mbActive = false;
diff --git a/sc/source/ui/namedlg/namedlg.cxx b/sc/source/ui/namedlg/namedlg.cxx
index 3be4af38a7f6..4f0164ef724c 100644
--- a/sc/source/ui/namedlg/namedlg.cxx
+++ b/sc/source/ui/namedlg/namedlg.cxx
@@ -351,9 +351,9 @@ void ScNameDlg::SetEntry(const OUString& rName, const OUString& rScope)
void ScNameDlg::RemovePushed()
{
- std::vector<ScRangeNameLine> maEntries = m_pRangeManagerTable->GetSelectedEntries();
+ std::vector<ScRangeNameLine> aEntries = m_pRangeManagerTable->GetSelectedEntries();
m_pRangeManagerTable->DeleteSelectedEntries();
- for (std::vector<ScRangeNameLine>::iterator itr = maEntries.begin(); itr != maEntries.end(); ++itr)
+ for (std::vector<ScRangeNameLine>::iterator itr = aEntries.begin(); itr != aEntries.end(); ++itr)
{
ScRangeName* pRangeName = GetRangeName(itr->aScope);
ScRangeData* pData = pRangeName->findByUpperName(ScGlobal::pCharClass->uppercase(itr->aName));
diff --git a/sc/source/ui/sidebar/CellAppearancePropertyPanel.cxx b/sc/source/ui/sidebar/CellAppearancePropertyPanel.cxx
index 670c55ac9292..5f39d8eb35bc 100644
--- a/sc/source/ui/sidebar/CellAppearancePropertyPanel.cxx
+++ b/sc/source/ui/sidebar/CellAppearancePropertyPanel.cxx
@@ -286,10 +286,10 @@ void CellAppearancePropertyPanel::NotifyItemUpdate(
if(pSvxLineItem)
{
- const editeng::SvxBorderLine* mbLineItem = pSvxLineItem->GetLine();
- mnIn = mbLineItem->GetInWidth();
- mnOut = mbLineItem->GetOutWidth();
- mnDis = mbLineItem->GetDistance();
+ const editeng::SvxBorderLine* pLineItem = pSvxLineItem->GetLine();
+ mnIn = pLineItem->GetInWidth();
+ mnOut = pLineItem->GetOutWidth();
+ mnDis = pLineItem->GetDistance();
if(mnIn == 0 && mnOut == 0 && mnDis == 0)
mbBorderStyleAvailable = false;
diff --git a/sc/source/ui/sidebar/CellBorderUpdater.cxx b/sc/source/ui/sidebar/CellBorderUpdater.cxx
index 80fb3461f4a8..12a87773182e 100644
--- a/sc/source/ui/sidebar/CellBorderUpdater.cxx
+++ b/sc/source/ui/sidebar/CellBorderUpdater.cxx
@@ -41,7 +41,7 @@ void CellBorderUpdater::UpdateCellBorder(bool bTop, bool bBot, bool bLeft, bool
BitmapEx aBmpEx( aImg.GetBitmapEx() );
Bitmap aBmp( aBmpEx.GetBitmap() );
BitmapWriteAccess* pBmpAcc = aBmp.AcquireWriteAccess();
- const Size maBmpSize = aBmp.GetSizePixel();
+ const Size aBmpSize = aBmp.GetSizePixel();
if( pBmpAcc )
{
@@ -58,7 +58,7 @@ void CellBorderUpdater::UpdateCellBorder(bool bTop, bool bBot, bool bLeft, bool
pBmpAcc->SetLineColor( ::Application::GetSettings().GetStyleSettings().GetFieldTextColor() ) ;
pBmpAcc->SetFillColor( COL_BLACK);
- if(maBmpSize.Width() == 43 && maBmpSize.Height() == 43)
+ if(aBmpSize.Width() == 43 && aBmpSize.Height() == 43)
{
Point aTL(2, 1), aTR(42,1), aBL(2, 41), aBR(42, 41), aHL(2,21), aHR(42, 21), aVT(22,1), aVB(22, 41);
if( pMskAcc )
diff --git a/sc/source/ui/vba/vbaborders.cxx b/sc/source/ui/vba/vbaborders.cxx
index ab6c80f83ec1..c761f43dc993 100644
--- a/sc/source/ui/vba/vbaborders.cxx
+++ b/sc/source/ui/vba/vbaborders.cxx
@@ -485,18 +485,18 @@ lcl_areAllLineWidthsSame( const table::TableBorder& maTableBorder, bool bIsCell
uno::Any SAL_CALL ScVbaBorders::getLineStyle() throw (uno::RuntimeException, std::exception)
{
- table::TableBorder maTableBorder;
- m_xProps->getPropertyValue( sTableBorder ) >>= maTableBorder;
+ table::TableBorder aTableBorder;
+ m_xProps->getPropertyValue( sTableBorder ) >>= aTableBorder;
sal_Int32 aLinestyle = XlLineStyle::xlLineStyleNone;
- if ( lcl_areAllLineWidthsSame( maTableBorder, bRangeIsSingleCell ))
+ if ( lcl_areAllLineWidthsSame( aTableBorder, bRangeIsSingleCell ))
{
- if (maTableBorder.TopLine.LineDistance != 0)
+ if (aTableBorder.TopLine.LineDistance != 0)
{
aLinestyle = XlLineStyle::xlDouble;
}
- else if ( maTableBorder.TopLine.OuterLineWidth != 0 )
+ else if ( aTableBorder.TopLine.OuterLineWidth != 0 )
{
aLinestyle = XlLineStyle::xlContinuous;
}
diff --git a/sc/source/ui/vba/vbachart.cxx b/sc/source/ui/vba/vbachart.cxx
index 4e2ef575aaa2..3919969749d9 100644
--- a/sc/source/ui/vba/vbachart.cxx
+++ b/sc/source/ui/vba/vbachart.cxx
@@ -562,15 +562,15 @@ ScVbaChart::setSourceData( const css::uno::Reference< ::ooo::vba::excel::XRange
{
try
{
- uno::Sequence< table::CellRangeAddress > mRangeAddresses(1);
- table::CellRangeAddress mSingleRangeAddress;
+ uno::Sequence< table::CellRangeAddress > aRangeAddresses(1);
+ table::CellRangeAddress aSingleRangeAddress;
uno::Reference< sheet::XCellRangeAddressable > xAddressable( _xCalcRange->getCellRange(), uno::UNO_QUERY_THROW );
- mSingleRangeAddress = xAddressable->getRangeAddress();
+ aSingleRangeAddress = xAddressable->getRangeAddress();
- mRangeAddresses[0] = mSingleRangeAddress;
+ aRangeAddresses[0] = aSingleRangeAddress;
- mxTableChart->setRanges(mRangeAddresses);
+ mxTableChart->setRanges(aRangeAddresses);
bool bsetRowHeaders = false;
bool bsetColumnHeaders = false;
@@ -579,8 +579,8 @@ ScVbaChart::setSourceData( const css::uno::Reference< ::ooo::vba::excel::XRange
if ( pRange )
{
ScDocument& rDoc = pRange->getScDocument();
- bsetRowHeaders = rDoc.HasRowHeader( static_cast< SCCOL >( mSingleRangeAddress.StartColumn ), static_cast< SCROW >( mSingleRangeAddress.StartRow ), static_cast< SCCOL >( mSingleRangeAddress.EndColumn ), static_cast< SCROW >( mSingleRangeAddress.EndRow ), static_cast< SCTAB >( mSingleRangeAddress.Sheet ) );
- bsetColumnHeaders = rDoc.HasColHeader( static_cast< SCCOL >( mSingleRangeAddress.StartColumn ), static_cast< SCROW >( mSingleRangeAddress.StartRow ), static_cast< SCCOL >( mSingleRangeAddress.EndColumn ), static_cast< SCROW >( mSingleRangeAddress.EndRow ), static_cast< SCTAB >( mSingleRangeAddress.Sheet ));
+ bsetRowHeaders = rDoc.HasRowHeader( static_cast< SCCOL >( aSingleRangeAddress.StartColumn ), static_cast< SCROW >( aSingleRangeAddress.StartRow ), static_cast< SCCOL >( aSingleRangeAddress.EndColumn ), static_cast< SCROW >( aSingleRangeAddress.EndRow ), static_cast< SCTAB >( aSingleRangeAddress.Sheet ) );
+ bsetColumnHeaders = rDoc.HasColHeader( static_cast< SCCOL >( aSingleRangeAddress.StartColumn ), static_cast< SCROW >( aSingleRangeAddress.StartRow ), static_cast< SCCOL >( aSingleRangeAddress.EndColumn ), static_cast< SCROW >( aSingleRangeAddress.EndRow ), static_cast< SCTAB >( aSingleRangeAddress.Sheet ));
}
mxTableChart->setHasRowHeaders(bsetRowHeaders);
mxTableChart->setHasColumnHeaders(bsetColumnHeaders);
@@ -606,8 +606,8 @@ ScVbaChart::setSourceData( const css::uno::Reference< ::ooo::vba::excel::XRange
}
else
{
- sal_Int32 nRows = mSingleRangeAddress.EndRow - mSingleRangeAddress.StartRow;
- sal_Int32 nCols = mSingleRangeAddress.EndColumn - mSingleRangeAddress.StartColumn;
+ sal_Int32 nRows = aSingleRangeAddress.EndRow - aSingleRangeAddress.StartRow;
+ sal_Int32 nCols = aSingleRangeAddress.EndColumn - aSingleRangeAddress.StartColumn;
// AutoDetect emulation
if ( nRows > nCols )
setPlotBy( xlColumns );
diff --git a/sc/source/ui/vba/vbawindows.cxx b/sc/source/ui/vba/vbawindows.cxx
index 0b0b54a1ecf6..230aaf51fc13 100644
--- a/sc/source/ui/vba/vbawindows.cxx
+++ b/sc/source/ui/vba/vbawindows.cxx
@@ -67,10 +67,10 @@ public:
explicit WindowComponentEnumImpl( const uno::Reference< uno::XComponentContext >& xContext ) throw ( uno::RuntimeException ) : m_xContext( xContext )
{
uno::Reference< frame::XDesktop2 > xDesktop = frame::Desktop::create(m_xContext);
- uno::Reference< container::XEnumeration > mxComponents = xDesktop->getComponents()->createEnumeration();
- while( mxComponents->hasMoreElements() )
+ uno::Reference< container::XEnumeration > xComponents = xDesktop->getComponents()->createEnumeration();
+ while( xComponents->hasMoreElements() )
{
- uno::Reference< sheet::XSpreadsheetDocument > xNext( mxComponents->nextElement(), uno::UNO_QUERY );
+ uno::Reference< sheet::XSpreadsheetDocument > xNext( xComponents->nextElement(), uno::UNO_QUERY );
if ( xNext.is() )
m_components.push_back( xNext );
}
diff --git a/sc/source/ui/vba/vbaworksheets.cxx b/sc/source/ui/vba/vbaworksheets.cxx
index 221ec7e40c0d..d7d84355fc75 100644
--- a/sc/source/ui/vba/vbaworksheets.cxx
+++ b/sc/source/ui/vba/vbaworksheets.cxx
@@ -442,7 +442,7 @@ ScVbaWorksheets::Item(const uno::Any& Index, const uno::Any& Index2)
uno::Reference< script::XTypeConverter > xConverter = getTypeConverter(mxContext);
uno::Any aConverted;
aConverted = xConverter->convertTo( Index, cppu::UnoType<uno::Sequence< uno::Any >>::get() );
- SheetMap mSheets;
+ SheetMap aSheets;
uno::Sequence< uno::Any > sIndices;
aConverted >>= sIndices;
sal_Int32 nElems = sIndices.getLength();
@@ -452,9 +452,9 @@ ScVbaWorksheets::Item(const uno::Any& Index, const uno::Any& Index2)
ScVbaWorksheet* pWorkSheet = excel::getImplFromDocModuleWrapper<ScVbaWorksheet>( xWorkSheet );
uno::Reference< sheet::XSpreadsheet > xSheet( pWorkSheet->getSheet() , uno::UNO_QUERY_THROW );
uno::Reference< container::XNamed > xName( xSheet, uno::UNO_QUERY_THROW );
- mSheets.push_back( xSheet );
+ aSheets.push_back( xSheet );
}
- uno::Reference< container::XIndexAccess > xIndexAccess = new SheetCollectionHelper( mSheets );
+ uno::Reference< container::XIndexAccess > xIndexAccess = new SheetCollectionHelper( aSheets );
uno::Reference< XCollection > xSelectedSheets( new ScVbaWorksheets( this->getParent(), mxContext, xIndexAccess, mxModel ) );
return uno::makeAny( xSelectedSheets );
}
diff --git a/sc/source/ui/miscdlgs/anyrefdg.cxx b/sc/source/ui/miscdlgs/anyrefdg.cxx
index e0818fb5aa63..c0e292ee1576 100644
--- a/sc/source/ui/miscdlgs/anyrefdg.cxx
+++ b/sc/source/ui/miscdlgs/anyrefdg.cxx
@@ -514,14 +514,14 @@ void ScFormulaReferenceHelper::RefInputStart( formula::RefEdit* pEdit, formula::
//We want just pRefBtn and pRefEdit to be shown
//mark widgets we want to be visible, starting with pRefEdit
//and all its direct parents.
- winset m_aVisibleWidgets;
+ winset aVisibleWidgets;
pResizeDialog = pRefEdit->GetParentDialog();
vcl::Window *pContentArea = pResizeDialog->get_content_area();
for (vcl::Window *pCandidate = pRefEdit;
pCandidate && (pCandidate != pContentArea && pCandidate->IsVisible());
pCandidate = pCandidate->GetWindow(GetWindowType::RealParent))
{
- m_aVisibleWidgets.insert(pCandidate);
+ aVisibleWidgets.insert(pCandidate);
}
//same again with pRefBtn, except stop if there's a
//shared parent in the existing widgets
@@ -529,12 +529,12 @@ void ScFormulaReferenceHelper::RefInputStart( formula::RefEdit* pEdit, formula::
pCandidate && (pCandidate != pContentArea && pCandidate->IsVisible());
pCandidate = pCandidate->GetWindow(GetWindowType::RealParent))
{
- if (m_aVisibleWidgets.insert(pCandidate).second)
+ if (aVisibleWidgets.insert(pCandidate).second)
break;
}
- //hide everything except the m_aVisibleWidgets
- hideUnless(pContentArea, m_aVisibleWidgets, m_aHiddenWidgets);
+ //hide everything except the aVisibleWidgets
+ hideUnless(pContentArea, aVisibleWidgets, m_aHiddenWidgets);
}
if (!mbOldDlgLayoutEnabled)